@@ -14,10 +14,11 @@ def cli(ctx, src, template_path):
     # All remaining arguments are passed through to render context
     context = dict([arg.split('=') for arg in ctx.args if '=' in arg ])
 
+    engine.DEFAULT_TEMPLATE_PATH = template_path
+
     click.echo(
         engine.render(
             name=src,
-            jinja_env=engine.default_jinja_env(template_path),
             **context
         )
     )
